Contributing
============

We welcome contributions!

Start here:

- https://github.com/skygazer42/pyimgano/blob/main/CONTRIBUTING.md

Docs
----

- CLI reference: https://github.com/skygazer42/pyimgano/blob/main/docs/CLI_REFERENCE.md
- Publishing: https://github.com/skygazer42/pyimgano/blob/main/docs/PUBLISHING.md
